@@ -140,9 +140,10 @@ from alchemite_apiclient.model.new_col_fn_arg_weighted_ratio_all_of_arguments im
 from alchemite_apiclient.model.new_col_fn_arg_zero_if_zero import NewColFnArgZeroIfZero
 from alchemite_apiclient.model.new_col_fn_arg_zero_if_zero_all_of import NewColFnArgZeroIfZeroAllOf
 from alchemite_apiclient.model.new_columns import NewColumns
+from alchemite_apiclient.model.non_empty_categorical_column import NonEmptyCategoricalColumn
 from alchemite_apiclient.model.non_empty_continuous_column import NonEmptyContinuousColumn
 from alchemite_apiclient.model.non_empty_integer_categorical_column import NonEmptyIntegerCategoricalColumn
-from alchemite_apiclient.model.non_empty_string_categorical_column import NonEmptyStringCategoricalColumn
+from alchemite_apiclient.model.ot_sample_def_categorical import OTSampleDefCategorical
 from alchemite_apiclient.model.ot_sample_def_continuous import OTSampleDefContinuous
 from alchemite_apiclient.model.ot_sample_definition import OTSampleDefinition
 from alchemite_apiclient.model.ot_set_inputs import OTSetInputs
@@ -164,6 +165,7 @@ from alchemite_apiclient.model.part_new_columns import PartNewColumns
 from alchemite_apiclient.model.part_tar_fn_above import PartTarFnAbove
 from alchemite_apiclient.model.part_tar_fn_below import PartTarFnBelow
 from alchemite_apiclient.model.part_tar_fn_between import PartTarFnBetween
+from alchemite_apiclient.model.part_tar_fn_categoricals import PartTarFnCategoricals
 from alchemite_apiclient.model.part_tar_fn_single_tar import PartTarFnSingleTar
 from alchemite_apiclient.model.part_tar_fn_sum import PartTarFnSum
 from alchemite_apiclient.model.part_tar_fn_weighted_sum import PartTarFnWeightedSum
@@ -172,6 +174,7 @@ from alchemite_apiclient.model.prediction import Prediction
 from alchemite_apiclient.model.query_request import QueryRequest
 from alchemite_apiclient.model.query_response import QueryResponse
 from alchemite_apiclient.model.si_sample_def_categorical import SISampleDefCategorical
+from alchemite_apiclient.model.si_sample_def_categorical_column_values import SISampleDefCategoricalColumnValues
 from alchemite_apiclient.model.si_sample_def_continuous import SISampleDefContinuous
 from alchemite_apiclient.model.si_sample_definition import SISampleDefinition
 from alchemite_apiclient.model.sample_def_categorical import SampleDefCategorical
@@ -221,6 +224,10 @@ from alchemite_apiclient.model.tar_fn_below import TarFnBelow
 from alchemite_apiclient.model.tar_fn_below_all_of import TarFnBelowAllOf
 from alchemite_apiclient.model.tar_fn_between import TarFnBetween
 from alchemite_apiclient.model.tar_fn_between_all_of import TarFnBetweenAllOf
+from alchemite_apiclient.model.tar_fn_exclude_categories import TarFnExcludeCategories
+from alchemite_apiclient.model.tar_fn_exclude_categories_all_of import TarFnExcludeCategoriesAllOf
+from alchemite_apiclient.model.tar_fn_include_categories import TarFnIncludeCategories
+from alchemite_apiclient.model.tar_fn_include_categories_all_of import TarFnIncludeCategoriesAllOf
 from alchemite_apiclient.model.tar_fn_sum_above import TarFnSumAbove
 from alchemite_apiclient.model.tar_fn_sum_above_all_of import TarFnSumAboveAllOf
 from alchemite_apiclient.model.tar_fn_sum_below import TarFnSumBelow
@@ -235,6 +242,7 @@ from alchemite_apiclient.model.tar_fn_weighted_sum_between import TarFnWeightedS
 from alchemite_apiclient.model.tar_fn_weighted_sum_between_all_of import TarFnWeightedSumBetweenAllOf
 from alchemite_apiclient.model.target_function import TargetFunction
 from alchemite_apiclient.model.train_request import TrainRequest
+from alchemite_apiclient.model.training_dataset_outliers_request import TrainingDatasetOutliersRequest
 from alchemite_apiclient.model.validate_request import ValidateRequest
 from alchemite_apiclient.model.value import Value
 from alchemite_apiclient.model.vector_prediction import VectorPrediction
